<template>
  <div class="createUser">
    <main>
      <div class="mainContent">
        <el-form
          ref="user"
          label-width="140px"
          autoComplete="on"
          :model="depart"
          :rules="createDepartRules"
          label-position="right"
        >
          <!-- 部门名称 -->
          <el-form-item class="optionItem" label="部门名称:" prop="departName">
            <el-input
              v-model="depart.departName"
              placeholder="请输入部门名称"
            ></el-input>
          </el-form-item>
          <!-- 上级部门 -->
          <el-form-item class="optionItems" label="上级部门:" prop="parentId">
            <el-select v-model="depart.parentId" placeholder="请输入上级部门">
              <el-option :value="mylabel">
                <el-tree
                  ref="tree"
                  :check-strictly="true"
                  :data="departList"
                  :props="defaultProps"
                  show-checkbox
                  @check-change="handleCheck"
                  default-expand-all
                  node-key="id"
                >
                </el-tree>
              </el-option>
            </el-select>
          </el-form-item>
          <!-- 部门类型 -->
          <el-form-item class="optionItem" label="部门类型:" prop="departType">
            <el-select v-model="depart.departType" placeholder="请选择部门类型">
              <el-option
                v-for="item in departTypeList"
                :key="item.id"
                :label="item.name"
                :value="item.id"
              >
              </el-option>
            </el-select>
          </el-form-item>
          <!--添加人员  -->
          <el-form-item class="optionItem add" label="添加人员:">
            <ul class="addPerson">
              <li
                v-for="(item, index) in checkedList"
                :key="index"
                @click="setLeader(index)"
              >
                <div class="li-item">
                  <div class="li-icon">
                    <i
                      :class="[
                        'el-icon-user-solid',
                        item.leader ? 'leader' : '',
                      ]"
                    ></i>
                  </div>
                  <label
                    style="font-size: 12px"
                    :class="[item.leader ? 'leader' : '']"
                    >{{ item.username }}</label
                  >
                </div>
              </li>
              <li class="li-btn">
                <i class="el-icon-plus" @click="openUser = true"></i>
              </li>
            </ul>
            <div class="card" v-if="openUser">
              <el-card class="box-card">
                <div slot="header" class="myclear">
                  <span>工作人员</span>
                  <div @click="addUser">确认</div>
                </div>
                <div class="scrollWrap">
                  <el-checkbox-group v-model="checkedUser">
                    <el-checkbox
                      v-for="user in userList"
                      :label="user.id"
                      :key="user.id"
                    >
                      {{ user.username}}
                    </el-checkbox>
                  </el-checkbox-group>
                </div>
                <div class="hidebar"></div>
              </el-card>
            </div>
          </el-form-item>
          <el-form-item style="margin-top: -40px">
            <label style="color: #ff0000ab"
              >红色代表部门领导，点击头像可设置部门领导</label
            >
          </el-form-item>
          <!-- 部门描述 -->
          <el-form-item class="optionItem" label="部门描述:" prop="departDes">
            <el-input
              type="textarea"
              :rows="4"
              v-model="depart.departDes"
              placeholder="请输入部门描述"
            ></el-input>
          </el-form-item>
        </el-form>
      </div>
    </main>
    <footer>
      <div class="optionBtn">
        <el-button @click="handleClose">取消</el-button>
        <el-button type="primary" class="btn submit" @click="handleUser"
          >确定</el-button
        >
      </div>
    </footer>
  </div>
</template>
<script>
import { getTypeList } from "@/utils/helper";
export default {
  data() {
    const validateNickname = (rule, value, callback) => {
      if (!value) {
        callback(new Error("请填写部门名称"));
      } else {
        callback();
      }
    };
    const validatePass = (rule, value, callback) => {
      if (!value) {
        callback();
      } else {
        callback();
      }
    };
    const validatePhone = (rule, value, callback) => {
      if (!value) {
        callback();
      } else {
        callback();
      }
    };
    return {
      depart: {
        departName: "",
        parentId: "",
        departType: "",
        departDes: "",
      },
      createDepartRules: {
        departName: [
          { required: true, trigger: "blur", validator: validateNickname },
        ],
        parentId: [
          { required: false, trigger: "blur", validator: validatePass },
        ],
        departType: [
          { required: false, trigger: "blur", validator: validatePhone },
        ],
        departDes: [{ required: false, trigger: "blur" }],
      },
      userList: [],
      departList: [],
      checkedUser: [],
      checkedList: [],
      openUser: false,
      departTypeList: [],
      selectOrg: {
        orgsid: [],
      },
      mylabel: "",
      defaultProps: {
        children: "children",
        label: "departName",
      },
    };
  },
  created() {
    const that = this;
    // 获取部门树形结构图
    this.getDepartTree();
    // 获取用户列表
    this.getUserList();
    // 获取部门类型列表
    this.getDepartTypeList();
  },
  methods: {
    handleUser() {
      this.$refs.user.validate((valid) => {
        if (valid) {
          const { depart, checkedList, selectOrg } = this;
          const arr = [];
          checkedList.forEach((item) => {
            arr.push({ leader: item.leader, userId: item.id });
          });
          console.log(arr);
          this.$axios({
            method: "post",
            url: "/sccg/depart/create",
            data: {
              departName: depart.departName,
              parentId: selectOrg.orgsid[0],
              departType: depart.departType,
              departDes: depart.departDes,
              departManagerList: arr,
            },
          }).then((res) => {
            if (res.code === 200) {
              this.$message({
                message: res.message,
                type: "success",
              });
              this.refresh();
            } else if (res.code === 2001) {
              this.$message({
                message: res.message,
                type: "error",
              });
              this.refresh();
            }
          });
        } else {
          return false;
        }
      });
    },
    // 获取部门树形结构图
    getDepartTree() {
      this.$axios({
        method: "get",
        url: "sccg/depart/tree",
      }).then((res) => {
        // console.log(res);
        // res.data.unshift({ id: 0, departName: "顶级菜单" });
        this.departList = res.data;
      });
    },
    // 获取所有用户信息
    getUserList() {
      // 获取所有用户信息、用户查询(暂时支持电话号码)
      this.$axios.get(`/sccg/depart/query_surplus_user`).then((res) => {
        if (res.code === 200) {
          this.userList = res.data;
        }
      });
    },
    addUser() {
      console.log(this.checkedUser);
      console.log(this.userList);
      this.checkedList = [];
      this.userList.forEach((item) => {
        this.checkedUser.forEach((child) => {
          if (item.id == child) {
            this.checkedList.push({
              id: item.id,
              username: item.username,
              leader: false,
            });
          }
        });
      });
      this.checkedList[0].leader = true;
      this.openUser = false;
    },
    handleClose() {
      this.$emit("changMyDialog", { flag: false });
    },
    // 获取部门类型
    async getDepartTypeList() {
      this.departTypeList = await getTypeList(1, "08");
    },
    handleCheck(data, checked) {
      this.depart.parentId = data.departName;
      // 获取当前选择的id在数组中的索引
      const indexs = this.selectOrg.orgsid.indexOf(data.id);
      // 如果不存在数组中，并且数组中已经有一个id并且checked为true的时候，代表不能再次选择。
      if (indexs < 0 && this.selectOrg.orgsid.length === 1 && checked) {
        this.$message({
          message: "只能选择一个部门！",
          type: "warning",
          showClose: true,
        });
        // 设置已选择的节点为false 很重要
        this.$refs.tree.setChecked(data, false);
      } else if (this.selectOrg.orgsid.length === 0 && checked) {
        // 发现数组为空 并且是已选择
        // 防止数组有值，首先清空，再push
        this.selectOrg.orgsid = [];
        this.selectOrg.orgsid.push(data.id);
      } else if (
        indexs >= 0 &&
        this.selectOrg.orgsid.length === 1 &&
        !checked
      ) {
        // 再次直接进行赋值为空操作
        this.selectOrg.orgsid = [];
        this.depart.parentId = "";
      }
    },
    // 设置领导
    setLeader(idx) {
      this.checkedList.forEach((item, index) => {
        item.leader = index === idx;
      });
    },
  },
  props: ["refresh", "changMyDialog"],
};
</script>
<style lang="scss" scoped>
.createUser {
  border-radius: 1px;
  background-color: #09152f;

  main {
    text-align: left;
    padding: 0 55px;
    background-color: #09152f;
    padding-bottom: 50px;

    .mainContent {
      display: flex;
      justify-content: center;
      padding-top: 50px;

      &::v-deep .el-form-item__label {
        color: #4b9bb7;
      }

      &::v-deep .el-input__inner {
        background-color: #09152f;
        border: 1px solid #17324c;
      }

      &::v-deep .el-textarea__inner {
        background-color: #09152f;
        border: 1px solid #17324c;
      }

      .addPerson {
        display: flex;
        list-style: none;
        padding: 0;
        flex-wrap: wrap;
        max-width: 280px;
        li {
          color: #fff;
          text-align: center;
          font-size: 30px;
          margin-left: 10px;
        }
      }
      .li-icon {
        background-color: #cccccc;
        width: 36px;
        height: 36px;
        border-radius: 50%;
        margin: 0 auto;
      }
      .li-btn {
        background-color: #cccccc;
        width: 36px;
        height: 36px;
        border-radius: 50%;
      }
      .el-form-item__content {
        width: 400px;

        .el-select {
          width: 100%;
        }
      }

      .optionHandleSp {
        display: flex;

        .areaNumber,
        .moreNumber {
          flex: 1;
        }

        .telNumber {
          flex: 2;
        }
      }
    }

    .add {
      position: relative;

      .card {
        position: absolute;
        z-index: 2000;
        right: 0;

        .box-card {
          min-height: 240px;
          max-height: 260px;
          overflow: hidden;
          background-color: #09152f;
          position: relative;
          max-width: 220px;

          .scrollWrap {
            overflow: scroll;
            height: 180px;
            position: relative;
            color: #4b9bb7;

            .el-checkbox-group {
              display: flex;
              flex-direction: column;

              .el-checkbox {
                line-height: 20px;
              }
            }
          }

          .myclear {
            width: 100%;
            line-height: 20px;
            color: #4b9bb7;
            display: flex;
            justify-content: space-between;
          }

          .hidebar {
            position: absolute;
            top: 77px;
            right: 20px;
            width: 20px;
            height: 180px;
            background-color: #09152f;
          }

          .item {
            line-height: 40px;
          }
        }
      }
    }
  }

  .li-item {
    display: flex;
    flex-direction: column;
  }

  .leader {
    color: red;
  }
  .el-input {
    width: 280px !important;
  }
  footer {
    border-top: 1px solid #fff;
    height: 80px;
    display: flex;
    align-items: center;
    justify-content: flex-end;
    padding-right: 20px;
  }
}
</style>